@@ -26,15 +26,7 @@ ExperimentHub <-
         }
     }
 
-    if (is.null(proxy)){
-        connect <- suppressWarnings(tryCatch({
-            readBin(hub, n=1L, what="raw")
-            TRUE
-        }, error = function(...){
-            FALSE
-        }))
-    } else {
-        connect <- TRUE
+    if (!is.null(proxy)) {
         message("Assuming valid proxy connection through '",
                 ifelse(is(proxy,"request"),
                        paste(unlist(proxy), collapse=":"),
@@ -42,10 +34,17 @@ ExperimentHub <-
                 "'",
                 "\n If you experience connection issues consider ",
                 "using 'localHub=TRUE'")
-    }
-    if (!connect && !localHub){
-        message("Cannot connect to ExperimentHub server, using 'localHub=TRUE' instead")
-        localHub <- !connect
+    } else if (!localHub) {
+        connect <- suppressWarnings(tryCatch({
+            readBin(hub, n=1L, what="raw")
+            TRUE
+        }, error = function(...){
+            FALSE
+        }))
+        if (!connect){
+            message("Cannot connect to ExperimentHub server, using 'localHub=TRUE' instead")
+            localHub <- FALSE
+        }
     }
     if(localHub){
         message("Using 'localHub=TRUE'\n",
@@ -92,8 +91,20 @@ setMethod("cache", "ExperimentHub",
     ## Try to install/load; don't fail if not available
     success <- paste0("see ?", pkg, " and browseVignettes('",
                       pkg, "') for documentation")
-    if (!pkg %in% rownames(installed.packages()))
-        BiocManager::install(pkg, suppressUpdates=TRUE)
+    nopkg <- paste0(pkg,
+                    " not installed.\n  Full functionality, documentation, ",
+                    "and loading of data might not be possible without installing")
+    if (!pkg %in% rownames(installed.packages())){
+        message(nopkg)        
+        if (interactive() &&
+            identical(AnnotationHub:::.ask(
+                                          paste0(txt="Install ", pkg),
+                                          values=c("yes", "no")),
+                      "yes")
+            ){
+            BiocManager::install(pkg, suppressUpdates=TRUE)
+        }        
+    }
     if (pkg %in% rownames(installed.packages())) {
         suppressPackageStartupMessages({
             require(pkg, quietly = TRUE, character.only = TRUE)
